@@ -8,6 +8,11 @@ from pathlib import Path
 import importlib.resources
 from urllib.parse import urlparse, parse_qs
 
+import socket
+import socketserver
+
+
+
 import remi
 import requests
 import typer
@@ -19,6 +24,23 @@ from smirnybot9001.config import SmirnyBot9001Config, create_config_and_inject_v
 from smirnybot9001.util import get_with_user_agent
 from smirnybot9001.color_table import get_color_table
 
+
+# monkey patch socketserver.TCPServer to use IPV6 by default
+socketserver.TCPServer.address_family = socket.AF_INET6
+
+# monkey patch updated server_bind() method into socketserver.TCPServer
+# to ensure that socket.IPV6_V6ONLY
+orig_server_bind = socketserver.TCPServer.server_bind
+
+
+def server_bind_ipv4_and_ipv6(self):
+    self.socket.setsockopt(socket.IPPROTO_IPV6, socket.IPV6_V6ONLY, 0)
+    orig_server_bind(self)
+
+
+socketserver.TCPServer.server_bind = server_bind_ipv4_and_ipv6
+
+
 APOCALYPSEBURG = 'https://img.bricklink.com/ItemImage/SN/0/70840-1.png'
 HARLEY = 'https://img.bricklink.com/ItemImage/MN/0/tlm134.png'
 DEFAULT_DISPLAY_WAV = 'happy-ending.wav'
@@ -200,7 +222,6 @@ class LEGOPart(LEGOThing):
     def scrape_info(self):
         self.name = f"{self.irc_command()} {self.number} Color: {self.color}"
         self.description = self.name
-        self.image_url = APOCALYPSEBURG
         bl_color_id, bl_part_id, name, bl_part_number, bricklink_url, image_url = extract_from_bricklink(self.number, self.color)
         print(bl_color_id, bl_part_id, name, bl_part_number, bricklink_url, image_url)
         self.name = bl_part_number
@@ -212,7 +233,7 @@ class LEGOPart(LEGOThing):
             pass
         self.image_url = image_url
         self.bricklink_url = bricklink_url
-        self.bricklink_url = f"https://www.bricklink.com/v2/catalog/catalogitem.page?ccName={self.number}"
+        # self.bricklink_url = f"https://www.bricklink.com/v2/catalog/catalogitem.page?ccName={self.number}"
 
 
 class InputButtonHBox(remi.gui.HBox):
